;; Generated package description from objed.el  -*- no-byte-compile: t -*-
(define-package "objed" "0.8.3" "Navigate and edit text objects." '((emacs "25") (cl-lib "0.5")) :commit "01f062187912785ebaa2961036802c777cbbc65d" :authors '(("Clemens Radermacher" . "clemera@posteo.net")) :maintainer '("Clemens Radermacher" . "clemera@posteo.net") :keywords '("convenience") :url "https://github.com/clemera/objed")
